@@ -73,39 +73,39 @@ class ElectricKiwiApi:
     async def get_active_session(self):
         session = await self.auth.request("get", ElectricKiwiEndpoint.session)
         check_status(session.status)
-        Session.from_dict(await session.json())
+        return Session.from_dict(await session.json())
 
     async def get_customer(self):
         customer = await self.auth.request("get",
                                            ElectricKiwiEndpoint.customer.format(customerNumber=self.customer_number))
         check_status(customer.status)
-        Customer.from_dict(await customer.json())
+        return Customer.from_dict(await customer.json())
 
     async def get_connection_details(self):
         connection_details = await self.auth.request("get", ElectricKiwiEndpoint.customerConnectionDetails.format(
             customerNumber=self.customer_number,
             connectionId=self.connection_id))
         check_status(connection_details.status)
-        CustomerConnection.from_dict(await connection_details.json())
+        return CustomerConnection.from_dict(await connection_details.json())
 
     async def get_billing_address(self):
         billing_address = await self.auth.request("get",
                                                   ElectricKiwiEndpoint.billingAddress.format(
                                                       customerNumber=self.customer_number))
         check_status(billing_address.status)
-        BillingAddress.from_dict(await billing_address.json())
+        return BillingAddress.from_dict(await billing_address.json())
 
     async def get_billing_frequency(self):
         billing_frequency = await self.auth.request("get", ElectricKiwiEndpoint.billingFrequency.format(
             customerNumber=self.customer_number))
         check_status(billing_frequency.status)
-        BillingFrequency.from_dict(await billing_frequency.json())
+        return BillingFrequency.from_dict(await billing_frequency.json())
 
     # @paginated(by_query_params=get_next_page)
     async def get_billing_bills(self, limit = 5, offset = 0):
         billing_bills = await self.auth.request("get", ElectricKiwiEndpoint.billingBills.format(customerNumber=self.customer_number, limit=limit, offset=offset))
         check_status(billing_bills.status)
-        Bills.from_dict(await billing_bills.json())
+        return Bills.from_dict(await billing_bills.json())
 
     async def get_billing_bill(self, bill_id):
         billing_bill = await self.auth.request("get",
@@ -113,7 +113,7 @@ class ElectricKiwiApi:
                                                    customerNumber=self.customer_number,
                                                    billId=bill_id))
         check_status(billing_bill.status)
-        Bill.from_dict(await billing_bill.json())
+        return Bill.from_dict(await billing_bill.json())
 
     async def get_bill_file(self, bill_id):
         bill_file = await self.auth.request("get",
@@ -121,14 +121,14 @@ class ElectricKiwiApi:
                                                 customerNumber=self.customer_number,
                                                 billId=bill_id))
         check_status(bill_file.status)
-        BillFile.from_dict(await bill_file.json())
+        return BillFile.from_dict(await bill_file.json())
 
     async def get_account_balance(self):
         account_balance = await self.auth.request("get",
                                                   ElectricKiwiEndpoint.accountBalance.format(
                                                       customerNumber=self.customer_number))
         check_status(account_balance.status)
-        AccountBalance.from_dict(await account_balance.json())
+        return AccountBalance.from_dict(await account_balance.json())
 
     async def get_consumption_summary(self, start_date, end_date):
         consumption_summary = await self.auth.request("get", ElectricKiwiEndpoint.consumptionSummary.format(
@@ -136,7 +136,7 @@ class ElectricKiwiApi:
             connectionId=self.connection_id),
                                                       json={start_date: start_date, end_date: end_date})
         check_status(consumption_summary.status)
-        ConsumptionSummary.from_dict(await consumption_summary.json())
+        return ConsumptionSummary.from_dict(await consumption_summary.json())
 
     async def get_consumption_averages(self, start_date, end_date, group_by="week"):
         consumption_average = await self.auth.request("get", ElectricKiwiEndpoint.consumptionAverages.format(
@@ -145,19 +145,19 @@ class ElectricKiwiApi:
                                                       json={start_date: start_date, end_date: end_date,
                                                             group_by: group_by})
         check_status(consumption_average.status)
-        ConsumptionAverage.from_dict(await consumption_average.json())
+        return ConsumptionAverage.from_dict(await consumption_average.json())
 
     async def get_hop_intervals(self):
         hop_intervals = await self.auth.request("get", ElectricKiwiEndpoint.hourOfPowerIntervals)
         check_status(hop_intervals.status)
-        HopIntervals.from_dict(await hop_intervals.json())
+        return HopIntervals.from_dict(await hop_intervals.json())
 
     async def get_hop(self):
         get_hop = await self.auth.request("get", ElectricKiwiEndpoint.hourOfPowerByConnection.format(
             customerNumber=self.customer_number,
             connectionId=self.connection_id))
         check_status(get_hop.status)
-        Hop.from_dict(await get_hop.json())
+        return Hop.from_dict(await get_hop.json())
 
     async def post_hop(self, hop_interval):
         data = {"start": hop_interval}
@@ -166,11 +166,11 @@ class ElectricKiwiApi:
             connectionId=self.connection_id),
                                            json=data)
         check_status(post_hop.status)
-        Hop.from_dict(await post_hop.json())
+        return Hop.from_dict(await post_hop.json())
 
     async def get_outage_info(self):
         outage_info = await self.auth.request("get",
                                               ElectricKiwiEndpoint.outageContactInformationForConnection.format(
                                                   connectionId=self.connection_id))
         check_status(outage_info.status)
-        OutageContact.from_dict(await outage_info.json())
+        return OutageContact.from_dict(await outage_info.json())
